@@ -15,9 +15,7 @@ from utilities.forms import (
     DynamicModelMultipleChoiceField, StaticSelect,
     APISelect, APISelectMultiple, StaticSelectMultiple, TagFilterField
 )
-from extras.forms import (
-    CustomFieldModelForm, CustomFieldBulkEditForm
-)
+from netbox.forms import NetBoxModelForm, NetBoxModelBulkEditForm, NetBoxModelFilterSetForm
 
 from .models import (
     ASN, ASNStatusChoices, Community, BGPSession,
@@ -68,7 +66,8 @@ class ASdotInput(TextInput):
         return super().render(name, value, attrs, renderer)
 
 
-class ASNFilterForm(BootstrapMixin, CustomFieldModelForm):
+class ASNFilterForm(NetBoxModelFilterSetForm):
+    model = ASN
     q = forms.CharField(
         required=False,
         label='Search'
@@ -87,14 +86,10 @@ class ASNFilterForm(BootstrapMixin, CustomFieldModelForm):
         required=False
     )
 
-    tag = TagFilterField(ASN)
-
-    class Meta:
-        model = ASN
-        fields = ['q', 'status', 'tenant']
+    tag = TagFilterField(model)
 
 
-class ASNForm(BootstrapMixin, CustomFieldModelForm):
+class ASNForm(NetBoxModelForm):
     number = ASNField(
         widget=ASdotInput
     )
@@ -106,6 +101,11 @@ class ASNForm(BootstrapMixin, CustomFieldModelForm):
         queryset=Site.objects.all(),
         required=False
     )
+    status = forms.ChoiceField(
+        required=False,
+        choices=ASNStatusChoices,
+        widget=StaticSelect()
+    )
     tenant = DynamicModelChoiceField(
         queryset=Tenant.objects.all(),
         required=False
@@ -129,7 +129,7 @@ class ASNForm(BootstrapMixin, CustomFieldModelForm):
         ]
 
 
-class ASNBulkEditForm(CustomFieldBulkEditForm):
+class ASNBulkEditForm(NetBoxModelBulkEditForm):
     pk = forms.ModelMultipleChoiceField(
         queryset=ASN.objects.all(),
         widget=forms.MultipleHiddenInput
@@ -148,10 +148,13 @@ class ASNBulkEditForm(CustomFieldBulkEditForm):
         widget=StaticSelect()
     )
 
-    class Meta:
-        nullable_fields = [
-            'tenant', 'description',
-        ]
+    model = ASN
+    fieldsets = (
+        (None, ('tenant', 'description', 'status')),
+    )
+    nullable_fields = (
+        'tenant', 'description',
+    )
 
 
 class CommunityForm(BootstrapMixin, forms.ModelForm):
@@ -159,6 +162,11 @@ class CommunityForm(BootstrapMixin, forms.ModelForm):
         queryset=Tag.objects.all(),
         required=False
     )
+    status = forms.ChoiceField(
+        required=False,
+        choices=ASNStatusChoices,
+        widget=StaticSelect()
+    )
     tenant = DynamicModelChoiceField(
         queryset=Tenant.objects.all(),
         required=False
@@ -197,7 +205,7 @@ class CommunityFilterForm(BootstrapMixin, forms.ModelForm):
         fields = ['q', 'status', 'tenant']
 
 
-class CommunityBulkEditForm(BootstrapMixin, BulkEditForm):
+class CommunityBulkEditForm(BulkEditForm):
     pk = forms.ModelMultipleChoiceField(
         queryset=Community.objects.all(),
         widget=forms.MultipleHiddenInput
@@ -222,7 +230,7 @@ class CommunityBulkEditForm(BootstrapMixin, BulkEditForm):
         ]
 
 
-class BGPSessionForm(BootstrapMixin, CustomFieldModelForm):
+class BGPSessionForm(NetBoxModelForm):
     name = forms.CharField(
         max_length=64,
         required=True
@@ -328,7 +336,8 @@ class BGPSessionAddForm(BGPSessionForm):
         return self.cleaned_data['remote_address']
 
 
-class BGPSessionFilterForm(BootstrapMixin, CustomFieldModelForm):
+class BGPSessionFilterForm(NetBoxModelFilterSetForm):
+    model = BGPSession
     q = forms.CharField(
         required=False,
         label='Search'
@@ -393,27 +402,20 @@ class BGPSessionFilterForm(BootstrapMixin, CustomFieldModelForm):
         required=False
     )
 
-    tag = TagFilterField(BGPSession)
-
-    class Meta:
-        model = BGPSession
-        fields = ['q', 'status', 'device_id']
+    tag = TagFilterField(model)
 
 
-class RoutingPolicyFilterForm(BootstrapMixin, CustomFieldModelForm):
+class RoutingPolicyFilterForm(NetBoxModelFilterSetForm):
+    model = RoutingPolicy
     q = forms.CharField(
         required=False,
         label='Search'
     )
 
-    tag = TagFilterField(RoutingPolicy)
-
-    class Meta:
-        model = RoutingPolicy
-        fields = ['q']
+    tag = TagFilterField(model)
 
 
-class RoutingPolicyForm(BootstrapMixin, CustomFieldModelForm):
+class RoutingPolicyForm(NetBoxModelForm):
     tags = DynamicModelMultipleChoiceField(
         queryset=Tag.objects.all(),
         required=False
@@ -424,20 +426,17 @@ class RoutingPolicyForm(BootstrapMixin, CustomFieldModelForm):
         fields = ['name', 'description']
 
 
-class BGPPeerGroupFilterForm(BootstrapMixin, CustomFieldModelForm):
+class BGPPeerGroupFilterForm(NetBoxModelFilterSetForm):
+    model = BGPPeerGroup
     q = forms.CharField(
         required=False,
         label='Search'
     )
 
-    tag = TagFilterField(BGPPeerGroup)
-
-    class Meta:
-        model = BGPPeerGroup
-        fields = ['q']
+    tag = TagFilterField(model)
 
 
-class BGPPeerGroupForm(BootstrapMixin, CustomFieldModelForm):
+class BGPPeerGroupForm(NetBoxModelForm):
     import_policies = DynamicModelMultipleChoiceField(
         queryset=RoutingPolicy.objects.all(),
         required=False,
