@@ -1,5 +1,5 @@
 from django.urls import path
-from extras.views import ObjectChangeLogView
+from netbox.views.generic import ObjectChangeLogView
 from .models import ASN, BGPSession, Community, RoutingPolicy, BGPPeerGroup
 
 from .views import (
@@ -33,27 +33,27 @@ urlpatterns = [
     path('community/<int:pk>/delete/', CommunityDeleteView.as_view(), name='community_delete'),
     path('community/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='community_changelog', kwargs={'model': Community}),
     # Sessions
-    path('session/', BGPSessionListView.as_view(), name='session_list'),
-    path('session/add/', BGPSessionAddView.as_view(), name='session_add'),
-    path('session/delete/', BGPSessionBulkDeleteView.as_view(), name='session_bulk_delete'),
-    path('session/<int:pk>/', BGPSessionView.as_view(), name='session'),
-    path('session/<int:pk>/edit/', BGPSessionEditView.as_view(), name='session_edit'),
-    path('session/<int:pk>/delete/', BGPSessionDeleteView.as_view(), name='session_delete'),
-    path('session/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='session_changelog', kwargs={'model': BGPSession}),
+    path('session/', BGPSessionListView.as_view(), name='bgpsession_list'),
+    path('session/add/', BGPSessionAddView.as_view(), name='bgpsession_add'),
+    path('session/delete/', BGPSessionBulkDeleteView.as_view(), name='bgpsession_bulk_delete'),
+    path('session/<int:pk>/', BGPSessionView.as_view(), name='bgpsession'),
+    path('session/<int:pk>/edit/', BGPSessionEditView.as_view(), name='bgpsession_edit'),
+    path('session/<int:pk>/delete/', BGPSessionDeleteView.as_view(), name='bgpsession_delete'),
+    path('session/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='bgpsession_changelog', kwargs={'model': BGPSession}),
     # Routing Policies
-    path('routing-policy/<int:pk>/', RoutingPolicyView.as_view(), name='routing_policy'),
-    path('routing-policy/', RoutingPolicyListView.as_view(), name='routing_policy_list'),
-    path('routing-policy/add/', RoutingPolicyEditView.as_view(), name='routing_policy_add'),
-    path('routing-policy/<int:pk>/edit/', RoutingPolicyEditView.as_view(), name='routing_policy_edit'),
-    path('routing-policy/delete/', RoutingPolicyBulkDeleteView.as_view(), name='routing_policy_bulk_delete'),
-    path('routing-policy/<int:pk>/delete/', RoutingPolicyDeleteView.as_view(), name='routing_policy_delete'),
-    path('routing-policy/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='routing_policy_changelog', kwargs={'model': RoutingPolicy}),
+    path('routing-policy/<int:pk>/', RoutingPolicyView.as_view(), name='routingpolicy'),
+    path('routing-policy/', RoutingPolicyListView.as_view(), name='routingpolicy_list'),
+    path('routing-policy/add/', RoutingPolicyEditView.as_view(), name='routingpolicy_add'),
+    path('routing-policy/<int:pk>/edit/', RoutingPolicyEditView.as_view(), name='routingpolicy_edit'),
+    path('routing-policy/delete/', RoutingPolicyBulkDeleteView.as_view(), name='routingpolicy_bulk_delete'),
+    path('routing-policy/<int:pk>/delete/', RoutingPolicyDeleteView.as_view(), name='routingpolicy_delete'),
+    path('routing-policy/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='routingpolicy_changelog', kwargs={'model': RoutingPolicy}),
     # Peer Groups
-    path('peer-group/', BGPPeerGroupListView.as_view(), name='peergroup_list'),
-    path('peer-group/add/', BGPPeerGroupEditView.as_view(), name='peergroup_add'),
-    path('peer-group/delete/', BGPPeerGroupBulkDeleteView.as_view(), name='peergroup_bulk_delete'),
-    path('peer-group/<int:pk>/', BGPPeerGroupView.as_view(), name='peergroup'),
-    path('peer-group/<int:pk>/edit/', BGPPeerGroupEditView.as_view(), name='peergroup_edit'),
-    path('peer-group/<int:pk>/delete/', BGPPeerGroupDeleteView.as_view(), name='peergroup_delete'),
-    path('peer-group/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='peergroup_changelog', kwargs={'model': BGPPeerGroup}),
+    path('peer-group/', BGPPeerGroupListView.as_view(), name='bgppeergroup_list'),
+    path('peer-group/add/', BGPPeerGroupEditView.as_view(), name='bgppeergroup_add'),
+    path('peer-group/delete/', BGPPeerGroupBulkDeleteView.as_view(), name='bgppeergroup_bulk_delete'),
+    path('peer-group/<int:pk>/', BGPPeerGroupView.as_view(), name='bgppeergroup'),
+    path('peer-group/<int:pk>/edit/', BGPPeerGroupEditView.as_view(), name='bgppeergroup_edit'),
+    path('peer-group/<int:pk>/delete/', BGPPeerGroupDeleteView.as_view(), name='bgppeergroup_delete'),
+    path('peer-group/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='bgppeergroup_changelog', kwargs={'model': BGPPeerGroup}),
 ]
